@@ -2,7 +2,7 @@ package Module::Provision;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.40.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.41.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
 
@@ -10,10 +10,10 @@ extends q(Module::Provision::Base);
 with    q(Module::Provision::TraitFor::Rendering);
 with    q(Module::Provision::TraitFor::CreatingDistributions);
 with    q(Module::Provision::TraitFor::UpdatingContent);
-with    q(Module::Provision::TraitFor::VCS);
-with    q(Module::Provision::TraitFor::AddingFiles);
 with    q(Module::Provision::TraitFor::PrereqDifferences);
 with    q(Module::Provision::TraitFor::CPANDistributions);
+with    q(Module::Provision::TraitFor::VCS);
+with    q(Module::Provision::TraitFor::AddingFiles);
 with    q(Module::Provision::TraitFor::Badges);
 
 1;
@@ -38,7 +38,7 @@ Module::Provision - Create Perl distributions with VCS and selectable toolchain
 
 =head1 Version
 
-This documents version v0.40.$Rev: 1 $ of L<Module::Provision>
+This documents version v0.41.$Rev: 1 $ of L<Module::Provision>
 
 =head1 Synopsis
 
@@ -328,6 +328,12 @@ Substitutes the existing version number for the new version number in all
 files in the F<MANIFEST>. Prompts for the major/minor and bump if the
 version numbers are not provided
 
+=head2 C<select_method>
+
+The pod coverage test falsely triggers on this module if this entry is
+removed. Caused by adding C<around> C<select_method> to
+L<Module::Provision::TraitFor::Badges>
+
 =head1 Diagnostics
 
 Add C<-D> to command line to turn on debug output
@@ -360,7 +366,7 @@ There are no known incompatibilities in this module
 
 There are no known bugs in this module.  Please report problems to
 http://rt.cpan.org/NoAuth/Bugs.html?Dist=Module-Provision.  Source
-code is on Github git://github.com/pjfl/Module-Provision.git. Patches
+code is on Github git://github.com/pjfl/p5-module-provision.git. Patches
 and pull requests are welcome
 
 =head1 Acknowledgements
@@ -375,7 +381,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
