@@ -31,6 +31,9 @@ has 'base'             => is => 'lazy', isa => Path, coerce => TRUE,
 has 'builder'          => is => 'lazy', isa => NonEmptySimpleStr,
    default             => 'MB';
 
+has 'coverage_server'  => is => 'ro',   isa => NonEmptySimpleStr,
+   default             => 'http://localhost:5000/coverage';
+
 has 'default_branches' => is => 'lazy', isa => HashRef,
    builder             => sub { { git => 'master', svn => 'trunk' } };
 
@@ -50,6 +53,9 @@ has 'hooks'            => is => 'lazy', isa => ArrayRef[NonEmptySimpleStr],
 has 'license'          => is => 'lazy', isa => NonEmptySimpleStr,
    default             => 'perl';
 
+has 'localdir'         => is => 'ro',   isa => NonEmptySimpleStr,
+   default             => 'local';
+
 has 'min_perl_ver'     => is => 'lazy', isa => NonEmptySimpleStr,
    default             => '5.010001';
 
@@ -58,6 +64,12 @@ has 'module_abstract'  => is => 'lazy', isa => NonEmptySimpleStr,
 
 has 'pub_repo_prefix'  => is => 'ro',   isa => SimpleStr, default => 'p5-';
 
+has 'remote_test_id'   => is => 'ro',   isa => NonEmptySimpleStr,
+   default             => 'test@testhost';
+
+has 'remote_script'    => is => 'ro',   isa => NonEmptySimpleStr,
+   default             => 'install_perl_module';
+
 has 'repository'       => is => 'lazy', isa => NonEmptySimpleStr,
    default             => 'repository';
 
@@ -68,7 +80,7 @@ has 'signing_key'      => is => 'lazy', isa => SimpleStr,
    default             => NUL;
 
 has 'tag_message'      => is => 'lazy', isa => NonEmptySimpleStr,
-   default             => 'Released';
+   default             => 'Releasing';
 
 has 'template_index'   => is => 'lazy', isa => NonEmptySimpleStr,
    default             => 'index.json';
@@ -87,7 +99,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding utf-8
 
 =head1 Name
 
@@ -137,6 +149,10 @@ directory in which to create new distributions
 A non empty simple string default to C<MB>. Selects the build system to
 use when creating new distributions
 
+=item C<coverage_server>
+
+The HTTP address of the coverage server. Used by the badge markup feature
+
 =item C<default_branches>
 
 A hash reference. The default branch names for the C<git> and C<svn> VCSs
@@ -172,6 +188,11 @@ method
 A non empty simple string which defaults to C<perl>. The default license for
 new distributions
 
+=item C<localdir>
+
+A non empty simple string which defaults to F<local>. The directory into which
+L<local::lib> should be installed
+
 =item C<min_perl_ver>
 
 Non empty simple string that is used as the default in the meta data of a
@@ -187,6 +208,16 @@ minted modules
 A simple string which default to C<p5->. Prepended to the lower cased
 distribution name it forms the name of the public repository
 
+=item C<remote_test_id>
+
+A non empty simple string that defaults to C<test@testhost>. The identity
+and host used to perform test installations
+
+=item C<remote_script>
+
+A non empty simple string that defaults to C<install_perl_module>. The command
+to execute on the test installation server
+
 =item C<repository>
 
 A non empty simple string which defaults to C<repository>. Name of the
@@ -205,7 +236,7 @@ as a fingerprint to find the author distribution signing key
 
 =item C<tag_message>
 
-Non empty simple string defaults to C<Released>. This is the default message
+Non empty simple string defaults to C<Releasing>. This is the default message
 to apply to the commit which creates a tagged release
 
 =item C<template_index>
@@ -264,7 +295,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
