@@ -5,7 +5,7 @@ use namespace::autoclean;
 use Class::Usul::Constants   qw( EXCEPTION_CLASS FALSE NUL OK TRUE );
 use Class::Usul::Crypt::Util qw( decrypt_from_config encrypt_for_config
                                  is_encrypted );
-use Class::Usul::Functions   qw( ensure_class_loaded io throw );
+use Class::Usul::Functions   qw( ensure_class_loaded throw );
 use Class::Usul::Types       qw( NonEmptySimpleStr );
 use English                  qw( -no_match_vars );
 use HTTP::Request::Common    qw( POST );
@@ -15,7 +15,7 @@ use Unexpected::Functions    qw( PathNotFound Unspecified );
 use Moo::Role;
 
 requires qw( add_leader config debug distname dist_version dumper
-             info loc log next_argv output yorn );
+             info loc log next_argv output run_cmd yorn );
 
 # Private attributes
 has '_debug_http_method' => is => 'ro', isa => NonEmptySimpleStr,
@@ -24,12 +24,12 @@ has '_debug_http_method' => is => 'ro', isa => NonEmptySimpleStr,
 
 # Private methods
 my $_convert_versions_to_paths = sub {
-   my ($self, $versions, $args) = @_; my $paths = []; $args ||= {};
+   my ($self, $versions, $args) = @_; my $paths = []; $args //= {};
 
    my $distname = $self->distname;
    my $subdir   = $args->{subdir} ? $args->{subdir}.'/' : NUL;
 
-   for my $version (@{ $versions || [] }) {
+   for my $version (@{ $versions // [] }) {
       for my $extn (qw(meta readme tar.gz)) {
          push @{ $paths }, "${subdir}${distname}-${version}.${extn}";
       }
@@ -38,6 +38,20 @@ my $_convert_versions_to_paths = sub {
    return $paths;
 };
 
+my $_dist_path = sub {
+   my ($self, $ver) = @_; my $file;
+
+   if ($ver) { $file = $self->distname."-${ver}.tar.gz" }
+   else {
+      $file = $self->distname.'-'.$self->dist_version.'.tar.gz';
+      -f $file or $file = $self->distname.'-v'.$self->dist_version.'.tar.gz';
+   }
+
+   -f $file or throw PathNotFound, [ $file ];
+
+   return $file
+};
+
 my $_log_http_debug = sub {
    my ($self, $type, $obj, $msg) = @_; $self->debug or return;
 
@@ -51,22 +65,21 @@ my $_log_http_debug = sub {
 };
 
 my $_read_rc_file = sub {
-   my $self = shift; my $dir = $self->config->my_home; my $attr = {};
+   my $self = shift; my $conf = $self->config; my $attr = {};
 
-   for (io( [ $dir, '.pause' ] )->chomp->getlines) {
+   for ($conf->my_home->catfile( '.pause' )->chomp->getlines) {
       ($_ and $_ !~ m{ \A \s* \# }mx) or next;
 
       my ($k, $v) = m{ \A \s* (\w+) (?: \s+ (.+))? \z }mx;
 
-      exists $attr->{ $k }
-         and throw error => 'Multiple entries for [_1]', args => [ $k ];
+      exists $attr->{ $k } and throw 'Multiple entries for [_1]', [ $k ];
       $attr->{ $k } = $v // NUL;
    }
 
    my $pword; exists $attr->{password}
       and $pword = $attr->{password}
       and is_encrypted $pword
-      and $attr->{password} = decrypt_from_config $self->config, $pword;
+      and $attr->{password} = decrypt_from_config $conf, $pword;
 
    return $attr;
 };
@@ -80,11 +93,11 @@ my $_ua_string = sub {
 };
 
 my $_write_rc_file = sub {
-   my ($self, $attr) = @_;
+   my ($self, $attr) = @_; my $conf = $self->config;
 
-   my $file = $self->config->my_home->catfile( '.pause' );
+   my $file = $conf->my_home->catfile( '.pause' );
 
-   $attr->{password} = encrypt_for_config $self->config, $attr->{password};
+   $attr->{password} = encrypt_for_config $conf, $attr->{password};
 
    $file->println( "${_} ".$attr->{ $_ } ) for (sort keys %{ $attr });
 
@@ -147,7 +160,7 @@ my $_delete_files = sub {
    $agent->agent( $self->$_ua_string ); $agent->env_proxy;
    $args->{http_proxy} and $agent->proxy( http => $args->{http_proxy} );
 
-   my $uri     = $args->{delete_files_uri} || $self->config->delete_files_uri;
+   my $uri     = $args->{delete_files_uri} // $self->config->delete_files_uri;
    my $request = $self->$_get_delete_request( $files, $args, $uri );
 
    $self->info( 'POSTing delete files request to [_1]', { args => [ $uri ] } );
@@ -157,24 +170,17 @@ my $_delete_files = sub {
 
 # Public methods
 sub cpan_upload : method {
-   my $self = shift; my $ver = $self->next_argv; my $file;
-
-   if ($ver) { $file = $self->distname."-${ver}.tar.gz" }
-   else {
-      $file = $self->distname.'-'.$self->dist_version.'.tar.gz';
-      -f $file or $file = $self->distname.'-v'.$self->dist_version.'.tar.gz';
-   }
-
-   -f $file or throw PathNotFound, [ $file ];
-
-   ensure_class_loaded( 'CPAN::Uploader' );
+   my ($self, $ver) = @_; $ver //= $self->next_argv;
 
+   my $file   = $self->$_dist_path( $ver );
    my $args   = $self->$_read_rc_file; $args->{subdir} //= lc $self->distname;
    my $prompt = $self->add_leader( $self->loc( 'Really upload to CPAN' ) );
 
    exists $args->{dry_run}
        or $args->{dry_run} = not $self->yorn( $prompt, FALSE, TRUE, 0 );
 
+   ensure_class_loaded( 'CPAN::Uploader' );
+
    CPAN::Uploader->upload_file( $file, $args );
    return OK;
 }
@@ -208,6 +214,21 @@ sub set_cpan_password : method {
    return OK;
 }
 
+sub test_upload : method {
+   my ($self, $ver) = @_; $ver //= $self->next_argv;
+
+   my $conf   = $self->config;
+   my $id     = $conf->remote_test_id;
+   my $script = $conf->remote_script;
+   my $file   = $self->$_dist_path( $ver );
+   my $args   = { in => 'stdin', out => 'stdout', };
+
+   $self->run_cmd( [ 'scp', $file, "${id}:/tmp" ] );
+   $self->run_cmd( [ 'ssh', '-t', $id, "${script} ${file}" ], $args );
+
+   return OK;
+}
+
 1;
 
 __END__
@@ -251,6 +272,12 @@ Uses L<CPAN::Uploader> to do the heavy lifting
 
 You must specify the version of the distribution to delete
 
+=head2 test_upload - Upload and install distribution on the test server
+
+   $exit_code = $self->test_upload;
+
+Upload and install distribution on the test server
+
 =head2 set_cpan_password - Set the PAUSE server password
 
    $exit_code = $self->set_cpan_password;
@@ -299,7 +326,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
