@@ -98,10 +98,34 @@ around '_build_vcs' => sub {
 };
 
 # Public Methods
+sub build_distribution : method {
+   my ($self, $verbose) = @_;
+
+   if ($self->builder eq 'DZ') {
+      $self->run_cmd( 'dzil build', $verbose ? { out => 'stdout' } : {} );
+   }
+   elsif ($self->builder eq 'MB') {
+      $self->run_cmd( 'perl Build.PL' );
+      $self->run_cmd( './Build dist', $verbose ? { out => 'stdout' } : {} );
+   }
+
+   return OK;
+}
+
+sub clean_distribution : method {
+   my ($self, $verbose) = @_;
+
+   if ($self->builder eq 'DZ') { $self->run_cmd( 'dzil clean' ) }
+   elsif ($self->builder eq 'MB') { $self->run_cmd( './Build distclean' ) }
+
+   return OK;
+}
+
 sub cover : method {
    my $self = shift; $self->chdir( $self->appldir );
 
-   $self->output ( 'Testing coverage [_1]', { args => [ $self->appldir ] } );
+   $self->quiet or
+      $self->output( 'Testing coverage [_1]', { args => [ $self->appldir ] } );
 
    my $cmd = $self->$_get_cover_build_command;
 
@@ -121,7 +145,7 @@ sub cover : method {
 sub create_directories {
    my $self = shift; my $perms = $self->exec_perms;
 
-   $self->output( 'Creating directories' );
+   $self->quiet or $self->output( 'Creating directories' );
    $self->appldir->exists or $self->appldir->mkpath( $perms );
    $self->builder eq 'MB'
       and ($self->incdir->exists or $self->incdir->mkpath( $perms ));
@@ -167,27 +191,16 @@ sub edit_project : method {
 sub generate_metadata {
    my ($self, $create) = @_; $self->chdir( $self->appldir );
 
-   my $mdf; my $verbose = $create ? FALSE : TRUE;
+   my $verbose = $create ? FALSE : TRUE; my $mdf = 'README.md';
 
-   if ($self->builder eq 'DZ') {
-      $self->run_cmd( 'dzil build', $verbose ? { out => 'stdout' } : {} );
-      $self->run_cmd( 'dzil clean' );
-      $mdf = 'README.md';
-   }
+      if ($self->builder eq 'DZ') { $self->build_distribution( $verbose ) }
    elsif ($self->builder eq 'MB') {
       $self->run_cmd( 'perl '.$self->project_file );
       $self->run_cmd( './Build manifest', $verbose ? { out => 'stdout' } : {} );
       $self->run_cmd( './Build distmeta', $verbose ? { out => 'stdout' } : {} );
-      $self->run_cmd( './Build distclean' );
-      $mdf = 'README.md';
-   }
-   elsif ($self->builder eq 'MI') {
-      $self->run_cmd( 'perl '.$self->project_file );
-      $self->run_cmd( 'make manifest', $verbose ? { out => 'stdout' } : {} );
-      $self->run_cmd( 'make clean' );
-      $mdf = 'README.mkdn';
    }
 
+   $self->clean_distribution( $verbose );
    return $create ? $mdf : undef;
 }
 
@@ -224,9 +237,7 @@ sub select_project : method {
 
    $self->chdir( my $dir = $project->appldir );
 
-   my $fh = IO::Handle->new; $fh->fdopen( 3, 'w' );
-
-   emit_to $fh, $dir; $fh->close;
+   io()->fdopen( 3, 'w' )->print( $dir )->close;
 
    return Module::Provision->new
       ( method => 'edit_project', noask => TRUE, quiet => TRUE )->run;
@@ -286,6 +297,18 @@ variable
 
 =head1 Subroutines/Methods
 
+=head2 build_distribution - Build a CPAN distribution tarball
+
+   $self->build_distribution( $verbose );
+
+Builds a CPAN distribution tarball
+
+=head2 clean_distribution - Cleans up after a distribution build
+
+   $self->clean_distribution( $verbose );
+
+Cleans up after a distribution build
+
 =head2 cover - Create test coverage statistics
 
    $exit_code = $self->cover;
@@ -398,7 +421,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
