@@ -16,21 +16,21 @@ requires qw( add_leader appldir builder config dist_module exec_perms file
              incdir initial_wd loc log perms stash testdir vcs yorn );
 
 # Object attributes (public)
-option 'force'        => is => 'ro',   isa => Bool, default => FALSE,
+option 'force'        => is => 'ro',   isa => Bool,
    documentation      => 'Overwrite files if they already exist',
-   short              => 'f';
+   default            => FALSE, short => 'f';
 
-option 'templates'    => is => 'ro',   isa => SimpleStr, default => NUL,
+option 'templates'    => is => 'ro',   isa => SimpleStr, format => 's',
    documentation      => 'Non default location of the code templates',
-   format             => 's';
+   default            => NUL;
 
-has 'template_dir'    => is => 'lazy', isa => Directory,
-   coerce             => Directory->coercion, init_arg => undef;
+has 'template_dir'    => is => 'lazy', isa => Directory, coerce => TRUE,
+   init_arg           => undef;
 
 has 'template_list'   => is => 'lazy', isa => ArrayRef, init_arg => undef;
 
 # Object attributes (private)
-has '_template_index' => is => 'lazy', isa => Path, coerce => Path->coercion,
+has '_template_index' => is => 'lazy', isa => Path, coerce => TRUE,
    init_arg           => undef;
 
 # Private methods
@@ -85,17 +85,15 @@ sub _build_template_list {
       ( paths => [ $index ], storage_class => 'Any' )
       and return $self->$_merge_lists( $data );
    my $builders  = {
-      DZ => [ [ 'dist.ini',           '_appldir' ],
-              [ 'DZ_Build.PL',      [ '_appldir', 'Build.PL' ], ], ],
-      MB => [ [ 'Build.PL',           '_appldir' ], ],
-      MI => [ [ 'MI_Makefile.PL',   [ '_appldir', 'Makefile.PL' ], ], ], };
+      DZ => [ [ 'dist.ini',      '_appldir' ],
+              [ 'DZ_Build.PL', [ '_appldir', '.build.PL' ], ], ],
+      MB => [ [ 'Build.PL',      '_appldir' ], ], };
    my $templates = [ [ 'Changes',         '_appldir'     ],
                      [ 'MANIFEST.SKIP',   '_appldir'     ],
+                     [ 'travis.yml',    [ '_appldir', '.travis.yml' ] ],
                      [ 'perl_module.pm',  '_dist_module' ],
-                     [ '01always_pass.t', '_testdir'     ],
                      [ '02pod.t',         '_testdir'     ],
                      [ '03podcoverage.t', '_testdir'     ],
-                     [ '04critic.t',      '_testdir'     ],
                      [ '05kwalitee.t',    '_testdir'     ],
                      [ '06yaml.t',        '_testdir'     ],
                      [ '07podspelling.t', '_testdir'     ],
@@ -170,7 +168,7 @@ sub render_template {
 }
 
 sub render_templates {
-   my $self = shift; $self->output( 'Rendering templates' );
+   my $self = shift; $self->quiet or $self->output( 'Rendering templates' );
 
    for my $tuple (map { $self->expand_tuple( $_ ) } @{ $self->template_list }) {
       $self->render_template( @{ $tuple } );
@@ -306,7 +304,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
