@@ -4,21 +4,39 @@ use namespace::autoclean;
 
 use Class::Usul::Constants qw( EXCEPTION_CLASS FALSE OK TRUE );
 use Class::Usul::Functions qw( io is_win32 throw );
-use Class::Usul::Types     qw( Bool Str );
+use Class::Usul::Types     qw( Bool HashRef Str );
 use Perl::Version;
 use Scalar::Util           qw( blessed );
 use Unexpected::Functions  qw( Unspecified );
 use Moo::Role;
+use Class::Usul::Options;
 
-requires qw( add_leader appbase appldir branch chdir config default_branch
-             dist_version distname editor exec_perms generate_metadata
-             get_line loc next_argv output quiet run_cmd vcs );
+requires qw( add_leader appbase appldir branch build_distribution chdir config
+             cpan_upload default_branch dist_version distname editor exec_perms
+             extra_argv generate_metadata get_line loc next_argv output quiet
+             run_cmd test_upload update_version vcs );
+
+# Attribute constructors
+my $_build_cmd_line_flags = sub {
+   my $self = shift; my $opts = {};
+
+   for my $k (qw( release test upload nopush )) {
+      $self->extra_argv->[ 0 ] and $self->extra_argv->[ 0 ] eq $k
+          and $self->next_argv and $opts->{ $k } = TRUE;
+   }
+
+   return $opts;
+};
 
 # Public attributes
-has 'no_auto_rev'  => is => 'ro',  isa => Bool, default => FALSE,
-   documentation   => 'Do not turn on Revision keyword expansion';
+option 'no_auto_rev' => is => 'ro',   isa => Bool, default => FALSE,
+   documentation     => 'Do not turn on Revision keyword expansion';
 
-has '_new_version' => is => 'rwp', isa => Str;
+has 'cmd_line_flags' => is => 'lazy', isa => HashRef[Bool],
+   builder           => $_build_cmd_line_flags;
+
+# Private attributes
+has '_new_version'   => is => 'rwp',  isa => Str;
 
 # Private functions
 my $_get_state_file_name = sub {
@@ -81,7 +99,7 @@ my $_add_to_svn = sub {
 my $_commit_release_to_git = sub {
    my ($self, $msg) = @_;
 
-   $self->run_cmd( 'git add .'  ); $self->run_cmd( "git commit -m '${msg}'" );
+   $self->run_cmd( 'git add .' ); $self->run_cmd( "git commit -m '${msg}'" );
 
    return;
 };
@@ -106,9 +124,9 @@ my $_get_svn_repository = sub {
 my $_get_version_numbers = sub {
    my ($self, @args) = @_; $args[ 0 ] and $args[ 1 ] and return @args;
 
-   my $prompt = $self->add_leader( $self->loc( 'Enter major/minor 0 or 1'  ) );
+   my $prompt = '+Enter major/minor 0 or 1';
    my $comp   = $self->get_line( $prompt, 1, TRUE, 0 );
-      $prompt = $self->add_leader( $self->loc( 'Enter increment/decrement' ) );
+      $prompt = '+Enter increment/decrement';
    my $bump   = $self->get_line( $prompt, 1, TRUE, 0 ) or return @args;
    my ($from, $ver);
 
@@ -153,6 +171,25 @@ my $_initialize_svn = sub {
    return;
 };
 
+my $_push_to_git_remote = sub {
+   my $self = shift; my $info = $self->run_cmd( 'git remote -v' )->stdout;
+
+   (grep { m{ \(push\) \z }mx } split m{ \n }mx, $info)[ 0 ] or return;
+
+   my $params = $self->quiet ? {} : { out => 'stdout' };
+
+   $self->run_cmd( 'git push --all',  $params );
+   $self->run_cmd( 'git push --tags', $params );
+   return;
+};
+
+my $_push_to_remote = sub {
+   my $self = shift;
+
+   $self->vcs eq 'git' and $self->$_push_to_git_remote;
+   return;
+};
+
 my $_svn_ignore_meta_files = sub {
    my $self = shift; $self->chdir( $self->appldir );
 
@@ -164,6 +201,10 @@ my $_svn_ignore_meta_files = sub {
    return;
 };
 
+my $_wrap = sub {
+   my $self = shift; my $method = shift; return not $self->$method( @_ );
+};
+
 my $_add_tag_to_svn = sub {
    my ($self, $tag) = @_; my $params = $self->quiet ? {} : { out => 'stdout' };
 
@@ -178,7 +219,7 @@ my $_add_tag_to_svn = sub {
 };
 
 my $_commit_release = sub {
-   my $self = shift; my $msg = $self->config->tag_message;
+   my ($self, $tag) = @_; my $msg = $self->config->tag_message." v${tag}";
 
    $self->vcs eq 'git' and $self->$_commit_release_to_git( $msg );
    $self->vcs eq 'svn' and $self->$_commit_release_to_svn( $msg );
@@ -244,6 +285,35 @@ around 'dist_post_hook' => sub {
    return $r;
 };
 
+around 'release_distribution' => sub {
+   my ($orig, $self) = @_;
+
+   $self->cmd_line_flags->{test}
+      and $self->$_wrap( 'build_distribution' )
+      and $self->$_wrap( 'test_upload', $self->dist_version );
+
+   return $orig->( $self );
+};
+
+around 'release_distribution' => sub {
+   my ($orig, $self) = @_; my $res = $orig->( $self );
+
+   $self->cmd_line_flags->{upload}
+      and $self->$_wrap( 'build_distribution' )
+      and $self->$_wrap( 'cpan_upload' )
+      and $self->$_wrap( 'clean_distribution' );
+
+   return $res;
+};
+
+around 'release_distribution' => sub {
+   my ($orig, $self) = @_; my $res = $orig->( $self );
+
+   $self->cmd_line_flags->{nopush} or $self->$_push_to_remote;
+
+   return $res;
+};
+
 around 'substitute_version' => sub {
    my ($next, $self, $path, @args) = @_; my $r = $self->$next( $path, @args );
 
@@ -258,7 +328,10 @@ around 'update_version_pre_hook' => sub {
 };
 
 around 'update_version_post_hook' => sub {
-   my ($next, $self, @args) = @_; $self->_set__new_version( $args[ 1 ] );
+   my ($next, $self, @args) = @_;
+
+   $self->_set__new_version( $args[ 1 ] );
+   $self->clear_dist_version; $self->clear_module_metadata;
 
    my $result = $self->$next( @args );
 
@@ -292,19 +365,24 @@ sub get_emacs_state_file_path {
 }
 
 sub release : method {
+   my $self = shift; $self->release_distribution; return OK;
+}
+
+sub release_distribution {
    my $self = shift;
 
-   $self->update_version;  $self->generate_metadata;
-   $self->$_commit_release; $self->$_add_tag( $self->_new_version );
-
-   return OK;
+   $self->update_version;
+   $self->generate_metadata;
+   $self->$_commit_release( $self->_new_version );
+   $self->$_add_tag( $self->_new_version );
+   return TRUE;
 }
 
 sub set_branch : method {
    my $self = shift; my $bfile = $self->branch_file;
 
    my $old_branch = $self->branch;
-   my $new_branch = $self->next_argv || $self->default_branch;
+   my $new_branch = $self->next_argv // $self->default_branch;
 
    not $new_branch and $bfile->exists and $bfile->unlink and return OK;
        $new_branch and $bfile->println( $new_branch );
@@ -328,7 +406,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding utf-8
 
 =head1 Name
 
@@ -365,7 +443,7 @@ where it resets the revision number file
 Requires these attributes to be defined in the consuming class;
 C<appldir>, C<distname>, C<vcs>
 
-Defines the following attributes;
+Defines the following command line options;
 
 =over 3
 
@@ -400,7 +478,14 @@ state file
 
    $exit_code = $self->release;
 
-Updates the distribution version, commits the change and tags the new release
+Calls L</release_distribution>. Will optionally install the distribution
+on a test server, upload the distribution to CPAN and push the repository
+to the origin
+
+=head2 release_distribution
+
+Updates the distribution version, regenerates the metadata, commits the change
+and tags the new release
 
 =head2 set_branch - Set the VCS branch name
 
@@ -444,7 +529,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
